@@ -305,7 +305,7 @@ void regressionTree::selectBeam(marray<constructReg> &Beam, marray<constructReg>
    // put first into the beam without checking
    Beam[0] = Candidates[SortArray[0].value] ;
    BeamEst[0] = SortArray[0].key ;
-   swap(SortArray[SortArray.filled()-1], SortArray[0]) ;
+   mswap(SortArray[SortArray.filled()-1], SortArray[0]) ;
    SortArray.pushdownAsc(1, SortArray.filled()-1) ;
    
    int pos, beamIdx = 1 ;
@@ -316,7 +316,7 @@ void regressionTree::selectBeam(marray<constructReg> &Beam, marray<constructReg>
    while (i >= 1 && beamIdx < Beam.len())
    {
       i-- ;
-      swap(SortArray[i], SortArray[0]) ;
+      mswap(SortArray[i], SortArray[0]) ;
       SortArray.pushdownAsc(1, i) ;
       
       // check this constructReg if it is equal to any of 
